﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using ColorCode;
using SelectPdf;

namespace SelectPdf.Samples
{
    public partial class PageSettings : Form
    {
        private void BtnCreatePdf_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;
            string file = "Document.pdf";

            try
            {
                // create a new pdf document
                PdfDocument doc = new PdfDocument();

                // create a new pdf font
                PdfFont font = doc.AddFont(PdfStandardFont.Helvetica);
                font.Size = 18;

                // add a new page to the document 
                // (with specific page size, margins and orientation)
                PdfPage page = doc.AddPage(PdfCustomPageSize.A4,
                    new PdfMargins(0f), PdfPageOrientation.Portrait);

                // create a new text element and add it to the page
                PdfTextElement text = new PdfTextElement(0, 0, Helper.SomeText(), font);
                page.Add(text);

                // add a new page to the document
                // (with specific page size, margins and orientation)
                PdfPage page2 = doc.AddPage(PdfCustomPageSize.Letter,
                    new PdfMargins(20f), PdfPageOrientation.Landscape);

                // create a new text element and add it to the page
                PdfTextElement text2 = new PdfTextElement(0, 0, Helper.SomeText(), font);
                page2.Add(text2);

                // save pdf document
                doc.Save(file);

                // close pdf document
                doc.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(String.Format("Error: {0}", ex.Message),
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            finally
            {
                Cursor = Cursors.Arrow;
            }

            // open generated pdf
            try
            {
                System.Diagnostics.Process.Start(file);
            }
            catch
            {
                MessageBox.Show("Could not open generated pdf document",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public PageSettings()
        {
            InitializeComponent();

            try
            {
                // display highlighted sample code
                string code = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory +
                    "/../../" + "PageSettings.cs");
                WBSampleCode.DocumentText = new CodeColorizer().Colorize(code, Languages.CSharp);
            }
            catch
            {
                WBSampleCode.DocumentText = "Sample code not available";
            }
        }

    }
}
